import excel "$inpath/data/raw/GDPDEF.xls", sheet("GDPDEF") firstrow clear
gen year = year(DATE)
drop DATE

rename GDPDEF_NBD20100101 GDP_DEF_INDEX

save "$inpath/data/process/GDP_DEF.dta", replace 

use "$inpath/data/process/clean_data.dta"

merge m:1 year using "$inpath/data/process/GDP_DEF.dta" 
keep if _merge == 3
drop _merge

drop if home != 1 & net_equity >0 

gen wealth = liquid_wealth
gen income = total_income 
			
gen R   = (wealth >= (0.50*income))
gen BH  = (home==1 & LTV >=avg_value & !missing(LTV) & wealth > 0) if R !=1
gen BL =  (home==1 & LTV < avg_value & LTV>0 &!missing(LTV) & wealth > 0) if R !=1
gen EK =  (home!=1 & wealth<=0) if R !=1
gen HH =  (home==1 & no_mortgage==1  & wealth > 0) if R !=1
gen HNH = (home!=1 & wealth > 0 ) if R !=1

gen illiquid_wealth_kap = net_equity + val_IRA + val_other_real_estate + val_other_assets
gen wealth_k = liquid_wealth_kap + illiquid_wealth_kap
gen income_k    = labor_income_Kap
gen kap_age = age_head >=25 & age_head <=55
gen NHTM  = (wealth_k> (.5*income_k))
gen WHTM =  (illiquid_wealth_kap >0 & NHTM !=1)
gen PHTM =  (illiquid_wealth_kap <=0 & NHTM !=1)

egen fixed_income = mean(total_income)

local real_vars "income wealth"

foreach var in `real_vars' {
	gen real_`var' = `var' * (100/GDP_DEF_INDEX)
	}

local real_wealth "Real Non-Housing Wealth" 
local real_income "Real Income" 
local liquid_wealth "Non-Housing Wealth"
local total_income "Income" 
local LTV "Loan-to-Value Ratio"


replace illiquid_wealth = home_value + val_IRA + val_other_real_estate + val_other_assets
gen illiquid_debt = yearly_mort_pay 

** Here we define different measures of wealth 
gen WEALTH1_b = WEALTH1 + home_value  // This is the value of assets, net debt plus the home value (not net)
gen WEALTH4 =  liquid_wealth + illiquid_wealth - liquid_debt - illiquid_debt // This is net liquid and net illiquid wealth
gen WEALTH3 =  liquid_wealth + illiquid_wealth - liquid_debt  // This is liquid and illiquid wealth minus liquid debt
replace illiquid_wealth = net_equity + val_IRA + val_other_real_estate + val_other_assets //This redefines illiquid wealth using net equity instead of home value. 
gen WEALTH5 =  liquid_wealth + illiquid_wealth - liquid_debt  // Similar to WEALTH3 but uses net equity instead of home value. 

** Ratio of the different wealth measures
gen ratio_1 = WEALTH1/income
gen ratio_1b = WEALTH1_b/income
gen ratio_LW = liquid_wealth/income
gen ratio_2 = WEALTH2/income
gen ratio_3 = WEALTH3/income
gen ratio_4 = WEALTH4/income
gen ratio_5 = WEALTH5/income

gen loan_to_income = liquid_debt/income 
replace loan_to_income = liquid_debt/labor_income if EK == 1
replace total_mort = . if home != 1
replace home_value = . if home != 1
replace yearly_mort_pay = . if home != 1

**This breaks up the types of Ricardian households 
gen R_home = (home == 1) if R == 1
gen R_high= (home==1 & LTV >=avg_value & !missing(LTV)) if R_home== 1
gen R_low = (home==1 & LTV < avg_value & LTV>0 &!missing(LTV)) if R_home == 1
gen R_no  = (home==1 & no_mortgage==1 & wealth > 0 ) if R_home == 1
gen R_nohome = (home != 1) if R == 1
gen R_status = ""

local R "R_high R_low R_no R_nohome"

foreach x in `R' {
	replace R_status = "`x'" if `x' == 1
	}
	
** Calculates the percentiles brackets for real income and real wealth
local variables "real_income real_wealth"

foreach var in `variables' {

	egen `var'_10 = pctile(`var'), p(10)
	egen `var'_25 = pctile(`var'), p(25)
	egen `var'_50 = pctile(`var'), p(50)
	egen `var'_75 = pctile(`var'), p(75)
	egen `var'_90 = pctile(`var'), p(90)
	
	gen `var'_percentile = "a_p0_p10" if `var' <= `var'_10
		replace `var'_percentile = "b_p10_p25" if `var' > `var'_10 & `var' <= `var'_25
		replace `var'_percentile = "c_p25_p50" if `var' > `var'_25 & `var' <= `var'_50
		replace `var'_percentile = "d_p50_p75" if `var' > `var'_50 & `var' <= `var'_75
		replace `var'_percentile = "e_p75_p90" if `var' > `var'_75 & `var' <= `var'_90
		replace `var'_percentile = "f_p90_p100" if `var' > `var'_90
	
	}


** This creates the dummy variables for the classified households
	
gen prelim = "a_R" if R == 1
	replace prelim = "b_W-HTM" if R!=1 & home == 1 & wealth >0
	replace prelim = "c_P-HTM" if R!=1 & home !=1

gen prelim_b = "a_R" if R == 1
	replace prelim_b = "b_W-HTM" if HH == 1 | BL == 1 | BH == 1
	replace prelim_b = "c_P-HTM" if HNH == 1 | EK == 1
	

gen Household="" 

rename R  a_R
rename HH b_HH
rename BL c_BL
rename BH d_BH
rename HNH e_HNH
rename EK f_EK
local house "a_R d_BH c_BL f_EK e_HNH b_HH"

foreach type in `house' {
	replace Household = "`type'" if `type' == 1
}
	

gen n = 1 
sort Household
by Household: egen total_obs = count(n)
by Household: egen total_unemp = total(unemployed)
by Household: gen unemp_rate = (total_unemp/total_obs)*100

save "$inpath/data/process/FullData_All_Years.dta", replace

local years "1999 2001 2003 2005 2007 2009 2011 2013"

foreach year in `years' {
	preserve
		keep if year == `year'
		save "$inpath/data/process/FullData_`year'.dta", replace
	restore	
}
