use "$inpath/data/process/FullData_All_Years.dta", clear 

drop if Household ==""
gen count = 1
collapse (sum) count, by(year Household) fast

reshape wide count, i(year) j(Household)  string

gen total_count =0
gen cum_sum = 0 

local type "a_R b_HH c_BL d_BH e_HNH f_EK"
	foreach x in `type' {
		replace total_count = total_count + count`x'
		}

local weight "a_R b_HH c_BL d_BH e_HNH f_EK"

foreach x in `weight' {
	gen rate_`x' = (count`x'/total_count)*100
	
	replace cum_sum = cum_sum + rate_`x'
	gen `x' = cum_sum
	 
	}

replace f_EK = 100 if f_EK> 99.9

twoway (area f_EK year, color(forest_green)) (area e_HNH year, color(eltgreen)) (area d_BH year, color(edkblue)) (area c_BL year, color(ltblue)) (area b_HH year, color(eltblue)) (area a_R year, color(ebg)), xlabel(1999 (2) 2013) ylabel(0 (20) 100) /*
*/ legend(row(1) size(small) symxsize(11) label( 6 "Ricardian") label(5 "HH") label(4 "BL") label(3 "BH") label(2 "HNH") label(1 "EK") span)
capture graph export "$inpath/out/figures/EvolutionHouseholds.eps",  replace


tsset year
twoway (line rate_a_R year, yaxis(1) lcolor(ltblue) ytitle("Percent of Sample- Ricardian", size(med)) yscale(titlegap(*15))) /*
*/ (line rate_f_EK year, yaxis(2) lpattern(longdash) lcolor(forest_green) ytitle("Percent of Sample- EK", size(med) axis(2))), /*
*/ legend( row(1) region(lstyle(none)) nobox size(med) symxsize(10) label( 1 "Ricardian") label(2 "EK") span)  xlabel(1999 (2) 2013)
capture graph export "$inpath/out/figures/Evolution_EK_R.eps",  replace

graph bar (asis) rate_a_R rate_b_HH rate_c_BL rate_d_BH rate_e_HNH rate_f_EK, over(year, gap(0)) stack outergap(0) /*
*/ legend(row(1) size(small) symxsize(11) label( 6 "Ricardian") label(5 "HH") label(4 "BL") label(3 "BH") label(2 "HNH") label(1 "EK") span)
capture graph export "$inpath/out/figures/GraphEx2.eps",  replace


use "$inpath/data/process/FullData_All_Years.dta", clear 

local threshold 50

egen pc1= pctile(real_income), p(.00000000000000000001)
egen pc5= pctile(real_income), p(5)
egen pc95 = pctile(real_income), p(99)
graph twoway kdensity real_income if year == 1999 & real_income  <=pc95, bw(1e+04) xtitle("Real Income") ytitle("Density") xlabel(-50000 (50000) 300000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_income_1999_`threshold'.eps",  replace


graph twoway (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="a_R" , bw(1e+04) color(ebg) lwidth(medthick))  /*
*/	     (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH" , bw(1e+04) color(eltblue) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(ltblue) lwidth(medthick)) /*
*/           (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH" , bw(1e+04) color(edkblue) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(eltgreen) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK" , bw(1e+04) color(forest_green) lwidth(medthick)), /*
*/ytitle("Density") legend(row(1) size(small) symxsize(11) label( 1 "Ricardian") label(2 "HH") label(3 "BL") label(4 "BH") label(5 "HNH") label(6 "EK") span) xlabel(-50000 (50000) 300000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_income_HH_1999_`threshold'.eps",  replace

graph twoway (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="a_R", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_income if year == 2001 & real_income >=pc1 & real_income <=pc95 & Household =="a_R", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2003 & real_income >=pc1 & real_income <=pc95 & Household =="a_R", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_income if year == 2005 & real_income >=pc1 & real_income <=pc95 & Household =="a_R", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2007 & real_income >=pc1 & real_income <=pc95 & Household =="a_R", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2009 & real_income >=pc1 & real_income <=pc95 & Household =="a_R", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_income if year == 2011 & real_income >=pc1 & real_income <=pc95 & Household =="a_R", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2013 & real_income >=pc1 & real_income <=pc95 & Household =="a_R", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Income", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 300000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_income_a_R_`threshold'.eps",  replace

graph twoway (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_income if year == 2001 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2003 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_income if year == 2005 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2007 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2009 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_income if year == 2011 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2013 & real_income >=pc1 & real_income <=pc95 & Household =="b_HH", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Income", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 300000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_income_b_HH_`threshold'.eps",  replace


graph twoway (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_income if year == 2001 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2003 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_income if year == 2005 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2007 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2009 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_income if year == 2011 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2013 & real_income >=pc1 & real_income <=pc95 & Household =="c_BL", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Income", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 300000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_income_c_BL_`threshold'.eps",  replace


graph twoway (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_income if year == 2001 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2003 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_income if year == 2005 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2007 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2009 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_income if year == 2011 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2013 & real_income >=pc1 & real_income <=pc95 & Household =="d_BH", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Income", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 300000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_income_d_BH_`threshold'.eps",  replace

graph twoway (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_income if year == 2001 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2003 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_income if year == 2005 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2007 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2009 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_income if year == 2011 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2013 & real_income >=pc1 & real_income <=pc95 & Household =="e_HNH", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Income", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 300000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_income_e_HNH_`threshold'.eps",  replace


graph twoway (kdensity real_income if year == 1999 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_income if year == 2001 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2003 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_income if year == 2005 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_income if year == 2007 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2009 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_income if year == 2011 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_income if year == 2013 & real_income >=pc1 & real_income <=pc95 & Household =="f_EK", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Income", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 300000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_income_f_EK_`threshold'.eps",  replace


drop pc1 pc5 pc95

egen pc1= pctile(real_wealth), p(1)
egen pc5= pctile(real_wealth), p(5)
egen pc95 = pctile(real_wealth), p(90)

graph twoway kdensity real_wealth if year == 1999 & real_wealth >=pc1 & real_wealth <=pc95, bw(1e+04) xtitle("Real Non-Housing Wealth", size(medsmall)) ytitle("Density") xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_1999_`threshold'.eps",  replace


foreach date in `dates' {

graph twoway (kdensity real_wealth if year == `date' & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R" , bw(1e+04) color(ebg) lwidth(medthick)), /*
*/ytitle("Density") xtitle("") xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_onlyR_`date'_`threshold'.eps",  replace

graph twoway (kdensity real_wealth if year == `date' & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(eltblue) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == `date' & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(ltblue) lwidth(medthick)) /*
*/           (kdensity real_wealth if year == `date' & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(edkblue) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == `date' & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(eltgreen) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == `date' & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK" , bw(1e+04) color(forest_green) lwidth(medthick)), /*
*/ytitle("Density") legend(row(1) size(small) symxsize(11) label(1 "HH") label(2 "BL") label(3 "BH") label(4 "HNH") label(5 "EK") span) xtitle("") xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_HH_`date'_`threshold'.eps",  replace

}


graph twoway (kdensity real_wealth if year == 1999 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_wealth if year == 2001 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2003 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_wealth if year == 2005 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2007 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2009 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_wealth if year == 2011 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2013 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="a_R", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Non-Housing Wealth", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_a_R_`threshold'.eps",  replace

graph twoway (kdensity real_wealth if year == 1999 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_wealth if year == 2001 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2003 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_wealth if year == 2005 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2007 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2009 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_wealth if year == 2011 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2013 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="b_HH", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Non-Housing Wealth", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_b_HH_`threshold'.eps",  replace


graph twoway (kdensity real_wealth if year == 1999 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_wealth if year == 2001 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2003 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_wealth if year == 2005 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2007 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2009 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_wealth if year == 2011 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2013 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="c_BL", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Non-Housing Wealth", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_c_BL_`threshold'.eps",  replace


graph twoway (kdensity real_wealth if year == 1999 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_wealth if year == 2001 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2003 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_wealth if year == 2005 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2007 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2009 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_wealth if year == 2011 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2013 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="d_BH", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Non-Housing Wealth", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_d_BH_`threshold'.eps",  replace

graph twoway (kdensity real_wealth if year == 1999 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_wealth if year == 2001 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2003 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_wealth if year == 2005 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2007 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2009 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_wealth if year == 2011 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2013 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="e_HNH", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Non-Housing Wealth", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_e_HNH_`threshold'.eps",  replace


graph twoway (kdensity real_wealth if year == 1999 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK", bw(1e+04) color(gs5) lwidth(medthick))  /*
*/	     (kdensity real_wealth if year == 2001 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK", bw(1e+04) color(gs6) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2003 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK", bw(1e+04) color(gs7) lwidth(medthick)) /*
*/           (kdensity real_wealth if year == 2005 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK", bw(1e+04) color(gs8) lwidth(medthick)) /*
*/	     (kdensity real_wealth if year == 2007 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK", bw(1e+04) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2009 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK", bw(1e+04) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity real_wealth if year == 2011 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK", bw(1e+04) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity real_wealth if year == 2013 & real_wealth >=pc1 & real_wealth <=pc95 & Household =="f_EK", bw(1e+04) color(gs12) lwidth(medthick)), /*
*/xtitle("Real Non-Housing Wealth", size(medsmall) ) ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) xlabel(-50000 (50000) 200000, format(%24.0fc) labsize(small)) ylabel(#4,labsize(small)) yscale(titlegap(*10))
capture graph export "$inpath/out/figures/real_wealth_f_EK_`threshold'.eps",  replace



drop pc1 pc5 pc95

egen pc1= pctile(LTV), p(1)
egen pc5= pctile(LTV), p(5)
egen pc95 = pctile(LTV), p(95)

graph twoway (kdensity LTV if year == 1999 & LTV >=pc1 & LTV <=pc95 & Household =="c_BL", bw(0.75) color(gs5) lwidth(medthick))  /*
*/	     (kdensity LTV if year == 2001 & LTV >=pc1 & LTV <=pc95 & Household =="c_BL", bw(0.75) color(gs6) lwidth(medthick)) /*
*/	     (kdensity LTV if year == 2003 & LTV >=pc1 & LTV <=pc95 & Household =="c_BL", bw(0.75) color(gs7) lwidth(medthick)) /*
*/           (kdensity LTV if year == 2005 & LTV >=pc1 & LTV <=pc95 & Household =="c_BL", bw(0.75) color(gs8) lwidth(medthick)) /*
*/	     (kdensity LTV if year == 2007 & LTV >=pc1 & LTV <=pc95 & Household =="c_BL", bw(0.75) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity LTV if year == 2009 & LTV >=pc1 & LTV <=pc95 & Household =="c_BL", bw(0.75) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity LTV if year == 2011 & LTV >=pc1 & LTV <=pc95 & Household =="c_BL", bw(0.75) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity LTV if year == 2013 & LTV >=pc1 & LTV <=pc95 & Household =="c_BL", bw(0.75) color(gs12) lwidth(medthick)), /*
*/xtitle("Loan-to-Value Ratio") ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) 
capture graph export "$inpath/out/figures/LTV_BL_`threshold'.eps",  replace

graph twoway (kdensity LTV if year == 1999 & LTV <=pc95 & Household =="d_BH", bw(0.75) color(gs5) lwidth(medthick))  /*
*/	     (kdensity LTV if year == 2001 & LTV <=pc95 & Household =="d_BH", bw(0.75) color(gs6) lwidth(medthick)) /*
*/	     (kdensity LTV if year == 2003 & LTV <=pc95 & Household =="d_BH", bw(0.75) color(gs7) lwidth(medthick)) /*
*/           (kdensity LTV if year == 2005 & LTV <=pc95 & Household =="d_BH", bw(0.75) color(gs8) lwidth(medthick)) /*
*/	     (kdensity LTV if year == 2007 & LTV <=pc95 & Household =="d_BH", bw(0.75) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity LTV if year == 2009 & LTV <=pc95 & Household =="d_BH", bw(0.75) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity LTV if year == 2011 & LTV <=pc95 & Household =="d_BH", bw(0.75) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity LTV if year == 2013 & LTV <=pc95 & Household =="d_BH", bw(0.75) color(gs12) lwidth(medthick)), /*
*/xtitle("Loan-to-Value Ratio") ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span)
capture graph export "$inpath/out/figures/LTV_BH_`threshold'.eps",  replace

drop pc1 pc5 pc95

egen pc1= pctile(loan_to_income), p(1)
egen pc5= pctile(loan_to_income), p(5)
egen pc95 = pctile(loan_to_income), p(95)

graph twoway (kdensity loan_to_income if year == 1999 & loan_to_income >=pc1 & loan_to_income <=pc95 & Household =="f_EK", bw(0.75) color(gs5) lwidth(medthick))  /*
*/	     (kdensity loan_to_income if year == 2001 & loan_to_income >=pc1 & loan_to_income <=pc95 & Household =="f_EK", bw(0.75) color(gs6) lwidth(medthick)) /*
*/	     (kdensity loan_to_income if year == 2003 & loan_to_income >=pc1 & loan_to_income <=pc95 & Household =="f_EK", bw(0.75) color(gs7) lwidth(medthick)) /*
*/           (kdensity loan_to_income if year == 2005 & loan_to_income >=pc1 & loan_to_income <=pc95 & Household =="f_EK", bw(0.75) color(gs8) lwidth(medthick)) /*
*/	     (kdensity loan_to_income if year == 2007 & loan_to_income >=pc1 & loan_to_income <=pc95 & Household =="f_EK", bw(0.75) color(gs9) lwidth(medthick)) /*
*/ 	     (kdensity loan_to_income if year == 2009 & loan_to_income >=pc1 & loan_to_income <=pc95 & Household =="f_EK", bw(0.75) color(gs10) lwidth(medthick))/*
*/ 	     (kdensity loan_to_income if year == 2011 & loan_to_income >=pc1 & loan_to_income <=pc95 & Household =="f_EK", bw(0.75) color(gs11) lwidth(medthick)) /*
*/ 	     (kdensity loan_to_income if year == 2013 & loan_to_income >=pc1 & loan_to_income <=pc95 & Household =="f_EK", bw(0.75) color(gs12) lwidth(medthick)), /*
*/xtitle("Loan-to-Income Ratio") ytitle("Density") legend(row(1) size(small) symxsize(5) label( 1 "1999") label(2 "2001") label(3 "2003") label(4 "2005") label(5 "2007") label(6 "2009") label(7 "2011") label(8 "2013")span) 
capture graph export "$inpath/out/figures/Loan_To_Income_EK_`threshold'.eps",  replace


drop pc1 pc5 pc95
