local variables "real_wealth real_income" 
local type "row col"
local probs "a_p0_p10 b_p10_p25 c_p25_p50 d_p50_p75 e_p75_p90 f_p90_p100" 
		
local real_wealth "Real Non-Housing Wealth"
local real_income "Real Income" 

local dates "1999 2001 2003 2005 2007 2009 2011 2013"

foreach date in `dates' {
	use "$inpath/data/process/FullData_All_Years.dta", clear
	
	foreach prob in `probs' {
		cd "$inpath/out/rawtex"
		logout, save(`date'_IncomePercent_by_RW_`prob'.tex) dta tex replace: tabstat real_income  if real_wealth_percentile =="`prob'" , stat(p10 p25 p50 p75 p90)   column(var)
		} 
	
	foreach prob in `probs' {
		use "$inpath/out/rawtex/`date'_IncomePercent_by_RW_`prob'.dta", clear
		keep if v1 == "p10" | v1 == "p25" | v1 == "p50" | v1 == "p75" | v1 == "p90"
		rename v1 percent
		rename v2 `prob'
		sort percent
		tempfile IP_using
		
		if "`prob'" == "a_p0_p10" {
			save master, replace
			} 
		
		else { 
			save `IP_using', replace
			use master, clear
			merge percent using `IP_using'
			drop _merge
			sort percent
			save master, replace 
			} 
		
		}
		
		cd "$inpath/out/finaltex"
		dataout, tex head noauto save("`date'_IncomePercent_by_RW") replace
		
		
use "$inpath/data/process/FullData_All_Years.dta", clear


	cd "$inpath/out/rawtex"
	logout, save(`date'_Household_by_real_wealth_row.tex) dta tex replace: tab Household real_wealth_percentile, row nofreq
	logout, save(`date'_Household_by_real_income_row.tex) dta tex replace: tab Household real_income_percentile, row nofreq
	
	logout, save(`date'_Household_by_real_wealth_col.tex) dta tex replace: tab Household real_wealth_percentile, col nofreq
	logout, save(`date'_Household_by_real_income_col.tex) dta tex replace: tab Household real_income_percentile, col nofreq

	
	foreach var in `variables' {
		foreach x in `type' {
			use "$inpath/out/rawtex/`date'_Household_by_`var'_`x'.dta", clear
			drop v8
			keep if v1 == "a R" | v1 == "b HH" | v1 == "c BL" | v1 == "d BH" | v1 == "e HNH" | v1 =="f EK" | v1 == "Household"
			drop if v1 == "Household" 
			rename v1 House 
			destring(v2 v3 v4 v5 v6 v7), replace
			
			forvalues i=2/7 {
				gen v`i'_b = string(v`i', "%24.2fc")
				}
			
			rename v2_b p0_p10
			rename v3_b p10_p25
			rename v4_b p25_p50
			rename v5_b p50_p75
			rename v6_b p75_p90
			rename v7_b p90_p100
			
			drop v*
		
			cd "$inpath/out/finaltex"
		
		
			dataout, tex head noauto save("`date'_PercentHousehold_by_`var'_`x'") replace
			}
		}
	}
