/*******************************************************************************
*                              Housekeeping                                    *
*******************************************************************************/   
clear all

set more off
set maxvar 32767, perm

/*
Here you must set the directories of the project. By default, the log will be
saved in "$inpath/code"

$inpath is the base directory, where the replication file has been placed 
$psid_raw is the directory where the unzipped .txt file and J###### .do files from the PSID have been placed
*/

global inpath   "/mq/home/m1snm01/projects/hh_balance_fiscal"
global psid_raw "$inpath/data/raw/psid"

cap log close
log using "$inpath/code/hh_fiscal.log", replace

/*******************************************************************************
*                           Create Base Dataset                                *
*******************************************************************************/
/*
Run J######.do and J######_formats.do (these come with the PSID data)

Make sure to edit J######.do such that the using statement has the correct path "$psid_raw/J######.txt"
*/
do "$psid_raw/J283018.do"
do "$psid_raw/J283018_formats.do"

/*
Run rename_raw.do

This will rename all variables for later reshaping so we can get person-year observations
*/
do "$inpath/code/rename_raw.do"

/*
Run correct_coding.do

This will address topcoding and NA/Don't know answers so they don't influence results
*/
do "$inpath/code/correct_coding.do"

/*
Run reshape_psid.do

This will reshape the dataset to long and make some corrections, giving us a person-year file
*/
do "$inpath/code/reshape_psid.do"

/*
Here we will save the base dataset
*/
save "$inpath/data/process/clean_data.dta", replace
/*******************************************************************************
*                           Add Classifications                                *
*******************************************************************************/
/*
Run classify.do

This adds both our classifications and Kaplan classifications and creates several additional variables 
*/
do "$inpath/code/classify.do"
/*******************************************************************************
*                                 Analysis                                     *
*******************************************************************************/
/*
Run tables.do

This creates the tex tables
*/
do "$inpath/code/tables.do"

/*
Run gini.do

Gini index calculation
*/
do "$inpath/code/gini.do"
/*
Run figures.do

Generates figures
*/
do "$inpath/code/figures.do"
/*
Run comparison.do

Generates Kaplan comparisons
*/
do "$inpath/code/comparison.do"
/*
Run percentiles.do

Generates wealth percentile tables
*/
do "$inpath/code/percentiles.do"
/*
Run prep_transition.do

Prepares full file for transitions
*/
do "$inpath/code/prep_transition.do"












