library(dplyr)
library(readstata13)
library(ggplot2)
library(lubridate)
library(tidyr)
library(stargazer)

oldw <- getOption("warn")

projdir <- "/mq/home/m1snm01/projects/Cristina/PSID_Transitions"
datadir <- "/data/transitions"
outdir <- "/output"

setwd(paste0(projdir, datadir))

transitionlist <- list.files()

mydf <- data.frame(hh1=character(),
                   hh2=character(),
                   n=integer(),
                   rate=double(),
                   base_year=integer(),
                   stringsAsFactors=FALSE
)


for (i in 1:length(transitionlist)) {
  tempdat <- read.dta13(transitionlist[i])
  tempdat <- tempdat %>% 
    group_by(hh1, hh2) %>% 
    summarize(n = n()) %>% 
    mutate(rate = n / sum(n), base_year = 1997 + 2*i) %>% 
    ungroup() %>% 
    complete(hh1, hh2, fill = list(n = 0, rate = 0.00), base_year)
  
  mydf <- bind_rows(mydf, tempdat)
}

mydf$hh1 = as.factor(mydf$hh1)
mydf$hh2 = as.factor(mydf$hh2)
mydf$base_year = as.factor(mydf$base_year)

setwd(paste0(projdir,outdir))

for (i in 1:6) {
  tempdf <- mydf[which(mydf$hh1==levels(mydf$hh1)[i]),] %>% 
    select(hh2, rate, base_year)
  tempdf <- reshape(tempdf, idvar = "hh2", timevar = "base_year", direction = "wide")
  
  stargazer(tempdf[1:6,], out = paste0("transitions_from_", substring(levels(mydf$hh1)[i], 3),".tex"), summary = FALSE, rownames = FALSE)
}

